/////////////////////////////////////////////////////////////////////////////
//
// Undelete
//
// Copyright (C) 1998 Mark Russinovich and Bryce Cogswell
// Systems Internals - http://www.sysinternals.com
//
// See readme.txt for terms of use.
//
/////////////////////////////////////////////////////////////////////////////

//
// DriveProp.cpp : implementation file
//

#include "stdafx.h"
#include "Undelete.h"
#include "DriveProp.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#undef THIS_FILE
static char THIS_FILE[] = __FILE__;
#endif

/////////////////////////////////////////////////////////////////////////////
// CDriveProp dialog


CDriveProp::CDriveProp(CWnd* pParent /*=NULL*/)
	: CPropertyPage(CDriveProp::IDD)
{
	//{{AFX_DATA_INIT(CDriveProp)
	m_ImmediateDelete = FALSE;
	//}}AFX_DATA_INIT
}


void CDriveProp::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	//{{AFX_DATA_MAP(CDriveProp)
	DDX_Control(pDX, ID_PERCENT, m_PercentRecycle);
	DDX_Check(pDX, ID_DISABLEGLOBAL, m_ImmediateDelete);
	//}}AFX_DATA_MAP
}


BEGIN_MESSAGE_MAP(CDriveProp, CDialog)
	//{{AFX_MSG_MAP(CDriveProp)
	ON_BN_CLICKED(ID_DISABLEGLOBAL, OnDisableglobal)
	ON_WM_HSCROLL()
	ON_WM_CANCELMODE()
	//}}AFX_MSG_MAP
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////////////////
// CDriveProp message handlers

void CDriveProp::OnDisableglobal() 
{
	UpdateData();
	OnSetActive();	
	SetModified( TRUE );
}

void CDriveProp::OnHScroll(UINT nSBCode, UINT nPos, CScrollBar* pScrollBar) 
{
	CString percentString;

	if( nSBCode == TB_THUMBTRACK || nSBCode == TB_ENDTRACK ||
		nSBCode == TB_LINEUP || nSBCode == TB_LINEDOWN) { 
	
		m_RecycleSize = ((CSliderCtrl *)pScrollBar)->GetPos();
		percentString.Format( _T("%d%%"), m_RecycleSize);
		this->GetDlgItem(IDC_PERCENTSTRING)->SetWindowText( percentString );
		UpdateSizeStrings();
	}
	SetModified( TRUE );
	
	CPropertyPage::OnHScroll(nSBCode, nPos, pScrollBar);
}

void CDriveProp::OnCancelMode() 
{
	CPropertyPage::OnCancelMode();
	
	// TODO: Add your message handler code here
	
}

BOOL CDriveProp::OnInitDialog() 
{
	CPropertyPage::OnInitDialog();
	CString textString;
	
	CString percentString;

	CSliderCtrl *slider = (CSliderCtrl *) this->GetDlgItem(ID_PERCENT);

	OnSetActive();

	if( m_SizeOfDrive >= 1024*1024 ) {

		textString.Format("%.2fGB", ((float) m_SizeOfDrive)/(1024.0*1024.0) );

	} else if( m_SizeOfDrive >= 1024 ) {
		
		textString.Format("%.0fMB", ((float) m_SizeOfDrive)/(1024.0) );

	} else {

		textString.Format("%dKB", m_SizeOfDrive );
	}
	this->GetDlgItem(IDC_SIZEOFDRIVE)->SetWindowText( textString );
	UpdateSizeStrings();

	slider->SetRange(0, 100, FALSE );
	slider->SetTicFreq( 10 );
	slider->SetPos( m_RecycleSize );
	percentString.Format( _T("%d%%"), m_RecycleSize );
	this->GetDlgItem(IDC_PERCENTSTRING)->SetWindowText( percentString );
	
	return TRUE;  // return TRUE unless you set the focus to a control
	              // EXCEPTION: OCX Property Pages should return FALSE
}

VOID CDriveProp::UpdateSizeStrings()
{
	CString textString;
	float	sizeOfBin;

	sizeOfBin = (float) m_SizeOfDrive * (float) (m_RecycleSize/100.0);

	if( sizeOfBin >= 1024*1024 ) {

		textString.Format("%.2fGB", ((float) sizeOfBin)/(1024.0*1024.0) );

	} else if( sizeOfBin >= 1024 ) {
		
		textString.Format("%.0fMB", ((float) sizeOfBin)/(1024.0) );

	} else {

		textString.Format("%dKB", sizeOfBin );
	}
	this->GetDlgItem(IDC_SPACERESERVED)->SetWindowText( textString );
}

BOOL CDriveProp::OnSetActive()
{
	// make sure stuff didn't change
	if( m_GlobalProperties->m_ConfigureGlobal ) {

		this->GetDlgItem(ID_PERCENT)->EnableWindow( FALSE );	
		this->GetDlgItem(ID_PERCENTTEXT)->EnableWindow( FALSE );
		this->GetDlgItem(ID_DISABLEGLOBAL)->EnableWindow( FALSE );	
		this->GetDlgItem(IDC_RESERVESTATIC)->EnableWindow( FALSE );	
		this->GetDlgItem(IDC_SPACERESERVED)->EnableWindow( FALSE );		

	} else {

		this->GetDlgItem(ID_DISABLEGLOBAL)->EnableWindow( TRUE );	
	}

	if( m_ImmediateDelete || m_GlobalProperties->m_ConfigureGlobal ) {

		this->GetDlgItem(IDC_RESERVESTATIC)->EnableWindow( FALSE );	
		this->GetDlgItem(IDC_SPACERESERVED)->EnableWindow( FALSE );		
		this->GetDlgItem(ID_PERCENT)->EnableWindow( FALSE );	
		this->GetDlgItem(ID_PERCENTTEXT)->EnableWindow( FALSE );	
		this->GetDlgItem(IDC_PERCENTSTRING)->EnableWindow( FALSE );

	} else {
		
		this->GetDlgItem(IDC_PERCENTSTRING)->EnableWindow( TRUE );
		this->GetDlgItem(ID_PERCENT)->EnableWindow( TRUE );	
		this->GetDlgItem(ID_PERCENTTEXT)->EnableWindow( TRUE );	
		this->GetDlgItem(IDC_RESERVESTATIC)->EnableWindow( TRUE );	
		this->GetDlgItem(IDC_SPACERESERVED)->EnableWindow( TRUE );		
	}
	return CPropertyPage::OnSetActive();
}
