/////////////////////////////////////////////////////////////////////////////
//
// Undelete
//
// Copyright (C) 1998 Mark Russinovich and Bryce Cogswell
// Systems Internals - http://www.sysinternals.com
//
// See readme.txt for terms of use.
//
/////////////////////////////////////////////////////////////////////////////

#include "stdafx.h"
#include "winplace.h"


CWindowPlacement::CWindowPlacement(){

   // Note: "length" is inherited from WINDOWPLACEMENT
   length = sizeof(WINDOWPLACEMENT);
}


CWindowPlacement::~CWindowPlacement()
{}

//////////////////
// Restore window placement from profile key
BOOL CWindowPlacement::Restore(LPCSTR lpKeyName, CWnd* pWnd)
{
   GetProfileWP(lpKeyName);   
   
   // Only restore if window intersets the screen.
   //   
   CRect rcTemp, rcScreen(0,0,GetSystemMetrics(SM_CXSCREEN),
   GetSystemMetrics(SM_CYSCREEN));
   if (!::IntersectRect(&rcTemp, &rcNormalPosition, &rcScreen))
      return FALSE;   
	 
	pWnd->SetWindowPlacement(this);  // set placement
   return TRUE;
}

//////////////////
// Get window placement from profile.
void CWindowPlacement::GetProfileWP(LPCSTR lpKeyName)
{
   CWinApp *pApp = AfxGetApp();   

   ASSERT_VALID(pApp);

   flags   = pApp->GetProfileInt(lpKeyName, "wp.flags", flags);
	ptMinPosition.x = pApp->GetProfileInt(lpKeyName, "wp.ptMinPosition.x", 
      ptMinPosition.x);
	ptMinPosition.y = pApp->GetProfileInt(lpKeyName, "wp.ptMinPosition.y",
      ptMinPosition.y);
	ptMaxPosition.x = pApp->GetProfileInt(lpKeyName, "wp.ptMaxPosition.x", 
      ptMaxPosition.x);
	ptMaxPosition.y = pApp->GetProfileInt(lpKeyName, "wp.ptMaxPosition.y",
      ptMaxPosition.y);   
	  
	RECT& rc = rcNormalPosition;  
	rc.left  = pApp->GetProfileInt(lpKeyName, "wp.left",   rc.left);
	rc.right = pApp->GetProfileInt(lpKeyName, "wp.right",  rc.right);
	rc.top   = pApp->GetProfileInt(lpKeyName, "wp.top",    rc.top);
	rc.bottom= pApp->GetProfileInt(lpKeyName, "wp.bottom", rc.bottom);
}


////////////////
// Save window placement in app profile
void CWindowPlacement::Save(LPCSTR lpKeyName, CWnd* pWnd)
{
   pWnd->GetWindowPlacement(this);   
   WriteProfileWP(lpKeyName);
}


//////////////////
// Write window placement to app profile
void CWindowPlacement::WriteProfileWP(LPCSTR lpKeyName)
{
   CWinApp *pApp = AfxGetApp(); 
   
   ASSERT_VALID(pApp);
   pApp->WriteProfileInt(lpKeyName, "wp.showCmd",         showCmd);
   pApp->WriteProfileInt(lpKeyName, "wp.flags",           flags);
   pApp->WriteProfileInt(lpKeyName, "wp.ptMinPosition.x", ptMinPosition.x);
   pApp->WriteProfileInt(lpKeyName, "wp.ptMinPosition.y", ptMinPosition.y);
   pApp->WriteProfileInt(lpKeyName, "wp.ptMaxPosition.x", ptMaxPosition.x);
   pApp->WriteProfileInt(lpKeyName, "wp.ptMaxPosition.y", ptMaxPosition.y);
   pApp->WriteProfileInt(lpKeyName, "wp.left",  rcNormalPosition.left);
   pApp->WriteProfileInt(lpKeyName, "wp.right", rcNormalPosition.right);
   pApp->WriteProfileInt(lpKeyName, "wp.top",   rcNormalPosition.top);
   pApp->WriteProfileInt(lpKeyName, "wp.bottom",rcNormalPosition.bottom);
}


void CWindowPlacement::SaveListView(LPCSTR lpKeyName, int NumColumns, CListView* pWnd)
{
	int i;
	CListCtrl& pListWnd = pWnd->GetListCtrl();
	CWinApp *pApp = AfxGetApp();   
	CString  profileString;

	for( i = 0; i < NumColumns; i++ ) {

		m_ColumnWidth[i] = pListWnd.GetColumnWidth( i );
	}
	pApp->WriteProfileInt(lpKeyName, "wp.numcolumns", NumColumns );
	for( i = 0; i < NumColumns; i++ ) {

	   profileString.Format( "wp.column%d", i );
	   pApp->WriteProfileInt(lpKeyName, profileString, m_ColumnWidth[i] );
	}
}

void CWindowPlacement::RestoreListView(LPCSTR lpKeyName, int NumColumns, CListView* pWnd)
{
	int i;
	CWinApp *pApp = AfxGetApp();   
	CString  profileString;
	CListCtrl& pListWnd = pWnd->GetListCtrl();

	m_NumColumns = pApp->GetProfileInt(lpKeyName, "wp.numcolumns",
				0);   

	for( i = 0; i < NumColumns; i++ ) m_ColumnWidth[i] = 100;

	for( i = 0; i < m_NumColumns; i++ ) {
		
	   profileString.Format( "wp.column%d", i );
		m_ColumnWidth[i] = pApp->GetProfileInt(lpKeyName, profileString, 100 );
	}
	for( i = 0; i < m_NumColumns; i++ ) {

		pListWnd.SetColumnWidth( i, m_ColumnWidth[i] );
	}
}